@@ -135,11 +135,9 @@ class Case(object):
         runcase = cs_runcase.runcase(run_ref)
 
         if runcase.cmd_name == "code_saturne":
-            from Base.XMLinitialize import XMLinit
             from cs_package import package
             pkg = package(old_pkg.scriptdir)
         elif runcase.cmd_name == "neptune_cfd":
-            from core.XMLinitialize import XMLinit
             from nc_package import package
             pkg = package(old_pkg.scriptdir)
 
@@ -264,7 +262,6 @@ class Case(object):
         # 1) Load the xml file of parameters in order to update it
         #    with the __backwardCompatibility method.
 
-        from Base.XMLengine import Case
         from Pages.ScriptRunningModel import ScriptRunningModel
         from cs_exec_environment import \
             separate_args, get_command_single_value, update_command_single_value, assemble_args, enquote_arg
@@ -275,7 +272,6 @@ class Case(object):
             from core.XMLinitialize import XMLinit
 
         if self.subdomains:
-            self.update_runcase_path(d, self.label, xmlonly)
             cdirs = []
             for d in self.subdomains:
                 cdirs.append(os.path.join(self.label, d))
@@ -539,13 +535,18 @@ class Case(object):
         lines = l.readlines()
 
         tab = []
+
+        # autovnv compare log only for field of real values
         for i in range(len(lines)):
-            if lines[i].find("Support") != -1:
+            # only select section with "Type" (english and french) on first line
+            if lines[i].find("Type") != -1:
                 line = [x.replace("\""," ").strip() for x in lines[i].split(";")]
                 name = line[0]
                 info = [x.split(":") for x in line[1:]]
                 info = [[x[0].strip(),x[1].strip()] for x in info]
-                if info[1][1] not in ['i4', 'u4', 'c']:
+                # section with 4 informations (name, location, type, size)
+                # and of type r (real)
+                if len(info) == 3 and info[1][1] not in ['i4', 'u4', 'c'] and :
                     line = [x.strip() for x in lines[i+1].split(";")]
                     vals = [x.split(":") for x in line]
                     vals = [[x[0].strip(),x[1].strip()] for x in vals]
@@ -762,6 +763,7 @@ class Study(object):
         # Create cases
         os.chdir(self.__dest)
 
+        log_lines = []
         for c in self.Cases:
             if not os.path.isdir(c.label):
                 e = os.path.join(c.pkg.get_dir('bindir'), c.exe)
@@ -769,13 +771,16 @@ class Study(object):
                     os.mkdir(c.label)
                     os.chdir(c.label)
                     refdir = os.path.join(self.__repo, c.label)
+                    retval = 1
                     for node in os.listdir(refdir):
                         ref = os.path.join(self.__repo, c.label, node)
                         if node in c.subdomains:
                             cmd = e + " create --case " + node \
                                   + " --quiet --noref --copy-from " \
                                   + ref
-                            retval, t = run_autovnv_command(cmd, self.__log)
+                            node_retval, t = run_autovnv_command(cmd, self.__log)
+                            # negative retcode is kept
+                            retval = min(node_retval,retval)
                         elif os.path.isdir(ref):
                             shutil.copytree(ref, node, symlinks=True)
                         else:
@@ -787,11 +792,17 @@ class Study(object):
                           + " --quiet --noref --copy-from "    \
                           + os.path.join(self.__repo, c.label)
                     retval, t = run_autovnv_command(cmd, self.__log)
+                if retval == 0:
+                    log_lines += ['    - create case: ' + c.label]
+                else:
+                    log_lines += ['    - create case: %s --> FAILED' % c.label]
             else:
                 print("Warning: the case %s already exists in the destination." % c.label)
 
         os.chdir(repbase)
 
+        return log_lines
+
 
     def getRunDirectories(self):
         list_cases = []
@@ -983,9 +994,9 @@ class Studies(object):
         """
         for l, s in self.studies:
             self.reporting('  o Create study: ' + l)
-            s.createCases()
-            for c in s.getCasesLabel():
-                self.reporting('    - create case: ' + c)
+            log_lines = s.createCases()
+            for line in log_lines:
+                self.reporting(line)
 
 
     def compilation(self):
