@@ -41,7 +41,8 @@
 !> \param[in]     ncesmp        number of cells with mass source term
 !> \param[in]     icepdc        index of the ncepdp cells with head loss
 !> \param[in]     icetsm        index of cells with mass source term
-!> \param[in]     itypsm        mass source type for the variables (cf. cs_user_mass_source_terms)
+!> \param[in]     itypsm        mass source type for the variables
+!>                              (cf. cs_user_mass_source_terms)
 !> \param[in]     dt            time step (per cell)
 !> \param[in]     tslagr        coupling term of the lagangian module
 !> \param[in]     ckupdc        work array for the head loss
@@ -108,7 +109,7 @@ integer          istprv
 integer          iphydp, iprev
 integer          imucpp, idftnp, iswdyp
 
-integer          icvflb
+integer          icvflb, imasac
 integer          ivoid(1)
 
 double precision rnorm , d2s3, d1s3, divp23
@@ -802,12 +803,12 @@ if (ncesmp.gt.0) then
   ! Integer equal to 1 (for navsto: nb of sur-iter)
   iiun = 1
 
-  ! We incremente smbrs with -Gamma.var_prev and rovsdt with Gamma (*theta)
+  ! We incremente smbrs with -Gamma.var_prev and rovsdt with Gamma
   ivar = ik
 
   call catsma &
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
-   isto2t , thetav(ivar)    ,                                     &
+   isto2t ,                                                       &
    icetsm , itypsm(:,ivar)  ,                                     &
    volume , cvara_k         , smacel(:,ivar) , smacel(1,ipr) ,    &
    smbrk  , w2     , w4 )
@@ -816,12 +817,12 @@ if (ncesmp.gt.0) then
 
   call catsma &
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
-   isto2t , thetav(ivar)    ,                                     &
+   isto2t ,                                                       &
    icetsm , itypsm(:,ivar)  ,                                     &
    volume , cvara_ep        , smacel(:,ivar) , smacel(1,ipr) ,    &
    smbre  , w3     , w5 )
 
-  ! If we extrapolate the source terms we put Gamma Pinj in propce
+  ! If we extrapolate the source terms we put Gamma Pinj in c_st
   if (istprv.ge.0) then
     do iel = 1, ncel
       c_st_k_p(iel)   = c_st_k_p(iel)   + w4(iel)
@@ -835,7 +836,7 @@ if (ncesmp.gt.0) then
     enddo
   endif
 
-  ! Implicit part (theta is already taken into account in catsma)
+  ! Implicit part
   do iel = 1, ncel
     tinstk(iel) = tinstk(iel) + w2(iel)
     tinste(iel) = tinste(iel) + w3(iel)
@@ -892,6 +893,7 @@ if (ikecou.eq.1) then
   iccocg = 1
   inc    = 1
   iconvp = iconv (ivar)
+  imasac = 1
   idiffp = idiff (ivar)
   nswrgp = nswrgr(ivar)
   imligp = imligr(ivar)
@@ -913,7 +915,7 @@ if (ikecou.eq.1) then
   call bilsca &
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   iwarnp , imucpp , idftnp ,                                     &
+   iwarnp , imucpp , idftnp , imasac ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    cvara_k         , cvara_k         ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
@@ -960,6 +962,7 @@ if (ikecou.eq.1) then
   iccocg = 1
   inc    = 1
   iconvp = iconv (ivar)
+  imasac = 1
   idiffp = idiff (ivar)
   nswrgp = nswrgr(ivar)
   imligp = imligr(ivar)
@@ -981,7 +984,7 @@ if (ikecou.eq.1) then
   call bilsca &
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   iwarnp , imucpp , idftnp ,                                     &
+   iwarnp , imucpp , idftnp , imasac ,                            &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    cvara_ep        , cvara_ep        ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
@@ -1153,7 +1156,7 @@ call codits &
    cvara_k         , cvara_k         ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
    imasfl , bmasfl ,                                              &
-   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   viscf  , viscb  , viscf  , viscb  , rvoid  ,                   &
    rvoid  , rvoid  ,                                              &
    icvflb , ivoid  ,                                              &
    tinstk , smbrk  , cvar_k          , dpvar  ,                   &
@@ -1228,7 +1231,7 @@ call codits &
    cvara_ep        , cvara_ep        ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
    imasfl , bmasfl ,                                              &
-   viscf  , viscb  , rvoid  , viscf  , viscb  , rvoid  ,          &
+   viscf  , viscb  , viscf  , viscb  , rvoid  ,                   &
    rvoid  , rvoid  ,                                              &
    icvflb , ivoid  ,                                              &
    tinste , smbre  , cvar_ep         , dpvar  ,                   &
